pub struct SavedState {Show 20 fields
pub dkg_id: u64,
pub sign_id: u64,
pub sign_iter_id: u64,
pub threshold: u32,
pub dkg_threshold: u32,
pub total_signers: u32,
pub total_keys: u32,
pub signer: SignerState,
pub signer_id: u32,
pub state: State,
pub commitments: HashMap<u32, PolyCommitment>,
pub invalid_private_shares: HashMap<u32, BadPrivateShare>,
pub public_nonces: Vec<PublicNonce>,
pub public_keys: PublicKeys,
pub dkg_public_shares: BTreeMap<u32, DkgPublicShares>,
pub dkg_private_shares: BTreeMap<u32, DkgPrivateShares>,
pub dkg_private_begin_msg: Option<DkgPrivateBegin>,
pub dkg_end_begin_msg: Option<DkgEndBegin>,
pub verify_packet_sigs: bool,
pub coordinator_public_key: Option<PublicKey>,
/* private fields */
}Expand description
The saved state required to reconstruct a signer
Fields
dkg_id: u64current DKG round ID
sign_id: u64current signing round ID
sign_iter_id: u64current signing iteration ID
threshold: u32the threshold of the keys needed for a valid signature
dkg_threshold: u32the threshold of the keys needed for a valid DKG
total_signers: u32the total number of signers
total_keys: u32the total number of keys
signer: SignerStatethe Signer object
signer_id: u32the Signer ID
state: Statethe current state
commitments: HashMap<u32, PolyCommitment>map of polynomial commitments for each party party_id => PolyCommitment
invalid private shares signer_id => {shared_key, tuple_proof}
public_nonces: Vec<PublicNonce>public nonces for this signing round
public_keys: PublicKeysthe public keys for all signers and coordinator
the DKG public shares received in this round
the DKG private shares received in this round
dkg_private_begin_msg: Option<DkgPrivateBegin>the DKG private begin message received in this round
dkg_end_begin_msg: Option<DkgEndBegin>the DKG end begin message received in this round
verify_packet_sigs: boolwhether to verify the signature on Packets
coordinator_public_key: Option<PublicKey>coordinator public key