pub struct Signer<SignerType: SignerTrait> {Show 23 fields
pub dkg_id: u64,
pub sign_id: u64,
pub sign_iter_id: u64,
pub threshold: u32,
pub dkg_threshold: u32,
pub total_signers: u32,
pub total_keys: u32,
pub signer: SignerType,
pub signer_id: u32,
pub state: State,
pub commitments: HashMap<u32, PolyCommitment>,
pub decrypted_shares: HashMap<u32, HashMap<u32, Scalar>>,
pub decryption_keys: HashMap<u32, (u32, Point)>,
pub invalid_private_shares: HashMap<u32, BadPrivateShare>,
pub public_nonces: Vec<PublicNonce>,
pub network_private_key: Scalar,
pub public_keys: PublicKeys,
pub dkg_public_shares: BTreeMap<u32, DkgPublicShares>,
pub dkg_private_shares: BTreeMap<u32, DkgPrivateShares>,
pub dkg_private_begin_msg: Option<DkgPrivateBegin>,
pub dkg_end_begin_msg: Option<DkgEndBegin>,
pub verify_packet_sigs: bool,
pub coordinator_public_key: Option<PublicKey>,
/* private fields */
}Expand description
A state machine for a signing round
Fields
dkg_id: u64current DKG round ID
sign_id: u64current signing round ID
sign_iter_id: u64current signing iteration ID
threshold: u32the threshold of the keys needed for a valid signature
dkg_threshold: u32the threshold of the keys needed for a valid DKG
total_signers: u32the total number of signers
total_keys: u32the total number of keys
signer: SignerTypethe Signer object
signer_id: u32the Signer ID
state: Statethe current state
commitments: HashMap<u32, PolyCommitment>map of polynomial commitments for each party party_id => PolyCommitment
map of decrypted DKG private shares src_party_id => (dst_key_id => private_share)
decryption_keys: HashMap<u32, (u32, Point)>shared secrets used to decrypt private shares src_party_id => (signer_id, dh shared key)
invalid private shares signer_id => {shared_key, tuple_proof}
public_nonces: Vec<PublicNonce>public nonces for this signing round
network_private_key: Scalarthe private key used to sign messages sent over the network
public_keys: PublicKeysthe public keys for all signers and coordinator
the DKG public shares received in this round
the DKG private shares received in this round
dkg_private_begin_msg: Option<DkgPrivateBegin>the DKG private begin message received in this round
dkg_end_begin_msg: Option<DkgEndBegin>the DKG end begin message received in this round
verify_packet_sigs: boolwhether to verify the signature on Packets
coordinator_public_key: Option<PublicKey>coordinator public key
Implementations
Sourceimpl<SignerType: SignerTrait> Signer<SignerType>
impl<SignerType: SignerTrait> Signer<SignerType>
Sourcepub fn new<R: RngCore + CryptoRng>(
threshold: u32,
dkg_threshold: u32,
total_signers: u32,
total_keys: u32,
signer_id: u32,
key_ids: Vec<u32>,
network_private_key: Scalar,
public_keys: PublicKeys,
rng: &mut R,
) -> Result<Self, Error>
pub fn new<R: RngCore + CryptoRng>( threshold: u32, dkg_threshold: u32, total_signers: u32, total_keys: u32, signer_id: u32, key_ids: Vec<u32>, network_private_key: Scalar, public_keys: PublicKeys, rng: &mut R, ) -> Result<Self, Error>
create a Signer
Sourcepub fn load(state: &SavedState) -> Self
pub fn load(state: &SavedState) -> Self
Load a coordinator from the previously saved state
Sourcepub fn save(&self) -> SavedState
pub fn save(&self) -> SavedState
Save the state required to reconstruct the coordinator
Sourcepub fn process<R: RngCore + CryptoRng>(
&mut self,
packet: &Packet,
rng: &mut R,
) -> Result<Vec<Message>, Error>
pub fn process<R: RngCore + CryptoRng>( &mut self, packet: &Packet, rng: &mut R, ) -> Result<Vec<Message>, Error>
process the passed incoming message, and return any outgoing messages needed in response
Sourcepub fn dkg_ended<R: RngCore + CryptoRng>(
&mut self,
rng: &mut R,
) -> Result<Message, Error>
pub fn dkg_ended<R: RngCore + CryptoRng>( &mut self, rng: &mut R, ) -> Result<Message, Error>
DKG is done so compute secrets
do we have all DkgPublicShares?
Sourcepub fn can_dkg_end(&self) -> bool
pub fn can_dkg_end(&self) -> bool
do we have all DkgPublicShares and DkgPrivateShares?
Sourcepub fn dkg_end_begin(
&mut self,
dkg_end_begin: &DkgEndBegin,
) -> Result<Vec<Message>, Error>
pub fn dkg_end_begin( &mut self, dkg_end_begin: &DkgEndBegin, ) -> Result<Vec<Message>, Error>
handle incoming DkgEndBegin
handle incoming DkgPublicShares
handle incoming DkgPrivateShares